@@ -1,11 +1,13 @@
-from composio_griptape.toolset import ComposioToolSet
+from composio import Action, App, Tag, Trigger, WorkspaceType
 
-from composio.client.enums import Action, App, Tag
+from composio_griptape.toolset import ComposioToolSet
 
 
 __all__ = (
     "Action",
     "App",
     "Tag",
+    "WorkspaceType",
+    "Trigger",
     "ComposioToolSet",
 )
